<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\x6f\x72\144\x50\x72\x65\163\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\x6f\144\145\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\164\x61\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\x50\171\164\150\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\x65\166\x65\162\163\x65\x50\162\157\170\x79"; private const VARNISH_CACHE_SERVER = "\x31\62\x37\56\60\x2e\x30\56\61\72\x36\x30\70\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\x53\x5f\x4d\105\x54\x48\x4f\x44" => ["\166\141\154\x75\145" => "\144\x69\162\x65\143\164", "\162\x61\167" => false], "\127\x50\x5f\x44\105\x42\x55\107\x5f\104\111\x53\120\x4c\x41\131" => ["\x76\x61\154\165\145" => "\146\141\x6c\163\145", "\162\x61\x77" => true], "\x57\x50\x5f\x44\105\x42\125\x47\x5f\x4c\x4f\107" => ["\166\141\x6c\x75\145" => "\x74\162\165\x65", "\x72\x61\167" => true], "\103\117\x4e\103\101\x54\x45\x4e\101\124\105\137\123\x43\x52\x49\x50\x54\123" => ["\166\x61\154\x75\145" => "\146\x61\x6c\163\x65", "\x72\141\x77" => true], "\101\125\124\117\x53\x41\x56\x45\x5f\111\x4e\x54\105\122\126\101\x4c" => ["\x76\141\x6c\165\145" => 600, "\162\141\x77" => true], "\127\x50\x5f\120\x4f\123\x54\137\122\x45\126\x49\123\x49\x4f\x4e\x53" => ["\166\141\154\165\145" => 5, "\162\141\167" => true], "\x45\x4d\x50\124\x59\137\x54\x52\x41\123\x48\137\x44\101\x59\x53" => ["\166\x61\x6c\165\145" => 21, "\x72\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\x57\120\x5f\101\x4c\114\117\x57\x5f\x4d\125\114\x54\111\x53\x49\x54\105" => ["\166\141\154\165\x65" => "\164\162\x75\x65", "\162\141\x77" => true], "\x4d\x55\114\124\x49\123\x49\124\x45" => ["\x76\x61\154\x75\x65" => "\164\162\x75\145", "\x72\x61\167" => true], "\123\125\x42\104\117\x4d\101\111\x4e\x5f\x49\x4e\x53\124\101\x4c\114" => ["\x76\x61\154\x75\x65" => "\146\x61\x6c\163\x65", "\162\x61\167" => true], "\x44\x4f\x4d\x41\111\x4e\137\x43\x55\x52\x52\105\x4e\124\137\123\x49\x54\x45" => ["\166\141\154\x75\x65" => '', "\162\x61\x77" => false], "\120\x41\124\110\137\x43\125\x52\122\x45\x4e\x54\137\123\x49\124\105" => ["\x76\141\x6c\x75\x65" => "\x2f", "\162\x61\167" => false], "\123\111\x54\x45\137\111\104\x5f\103\125\x52\x52\x45\116\x54\x5f\x53\111\x54\x45" => ["\166\141\x6c\x75\145" => 1, "\162\x61\167" => true], "\102\114\x4f\107\x5f\x49\x44\137\x43\125\122\122\x45\x4e\x54\137\x53\x49\x54\105" => ["\x76\x61\x6c\x75\x65" => 1, "\162\x61\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto b5d86; f89dc: $this->databaseEntityManager = $databaseEntityManager; goto b1d98; E046b: parent::__construct($translator, $logger); goto c0163; A0bd1: $this->certificateEntityManager = $certificateEntityManager; goto f89dc; aba07: $this->databaseServerEntityManager = $databaseServerEntityManager; goto F1057; B0790: $this->domainNameParser = $domainNameParser; goto d779c; b1d98: $this->databaseUserEntityManager = $databaseUserEntityManager; goto aba07; b5d86: $this->configManager = $configManager; goto e9d8f; F1057: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto B0790; e9d8f: $this->siteEntityManager = $siteEntityManager; goto A0bd1; d779c: $this->validator = $validator; goto E046b; c0163: } public function index(Request $request) : Response { goto c01ff; E08ce: $user = $this->getUser(); goto C914c; A02db: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\x69\x74\x65\x73")); goto bd0ac; ebc08: return $response; goto Dbd9c; b7c47: if (true === $hasPermissions) { goto d6bd4; } goto A02db; C914c: $response = $this->render("\x46\162\x6f\x6e\164\145\156\x64\x2f\x53\x69\x74\x65\x2f\x4e\145\x77\x2f\x69\x6e\144\x65\170\56\x68\x74\x6d\154\56\x74\x77\x69\147", ["\165\163\145\162" => $user]); goto A7caa; Ab2a3: d6bd4: goto E08ce; bd0ac: goto Ac65e; goto Ab2a3; c01ff: $hasPermissions = $this->hasPermissions(); goto b7c47; A7caa: Ac65e: goto ebc08; Dbd9c: } public function newPythonSite(Request $request) : Response { goto Fff2f; Bc6db: goto b5c2f; goto B5219; Edfb9: if (!(true === $request->isMethod("\120\117\123\124"))) { goto C0943; } goto A64e9; fee83: $form = $this->createPythonSiteForm($pythonSettings); goto Edfb9; d109f: $pythonSettings = new PythonSettingsEntity(); goto fee83; Aaedf: e3f43: goto F9c7b; a7de6: C0943: goto Fc689; Fff2f: $hasPermissions = $this->hasPermissions(); goto Bc235; Af049: $response = $this->handleCreatePythonSiteForm($request, $form); goto ba0c3; E0f37: return $response; goto F1cab; ba0c3: if (!(false === is_null($response))) { goto e3f43; } goto d1ccc; db4c3: if (!(true === $form->isSubmitted())) { goto d55c4; } goto Af049; b81be: $user = $this->getUser(); goto d109f; Bc235: if (true === $hasPermissions) { goto db613; } goto ef26d; A64e9: $form->handleRequest($request); goto db4c3; B5219: db613: goto b81be; Ea1a8: b5c2f: goto E0f37; d1ccc: return $response; goto Aaedf; Fc689: $response = $this->render("\x46\x72\x6f\x6e\164\145\x6e\144\57\123\x69\x74\145\x2f\x4e\145\x77\x2f\x70\171\x74\150\x6f\x6e\56\150\x74\155\x6c\56\x74\167\x69\x67", ["\x75\x73\145\x72" => $user, "\146\x6f\162\x6d" => $form->createView(), "\x66\x6f\x72\x6d\x45\x72\x72\157\162\x73" => $this->formErrors]); goto Ea1a8; F9c7b: d55c4: goto a7de6; ef26d: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\x69\x74\145\x73")); goto Bc6db; F1cab: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto A88b4; A88b4: $form = $this->createForm("\101\160\160\134\x46\x6f\162\x6d\x5c\x53\151\x74\145\116\x65\167\x50\171\164\x68\x6f\156\x54\171\x70\x65", $pythonSettings, ["\x61\x63\x74\x69\x6f\156" => $this->generateUrl("\x63\154\160\137\x73\x69\x74\x65\x5f\x70\171\x74\150\157\x6e\x5f\156\x65\x77"), "\155\x65\164\150\x6f\x64" => "\120\x4f\123\x54", "\141\x74\164\x72" => ["\151\x64" => "\156\x65\167\x2d\160\171\x74\x68\157\156\55\163\151\164\145\55\x66\x6f\x72\155"]]); goto dc974; dc974: $form->add("\163\x75\x62\x6d\151\x74", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\154\x61\163\163" => "\x62\x74\x6e\x20\142\164\x6e\55\154\x67\40\x62\164\156\55\x62\x6c\165\x65"], "\154\141\x62\x65\154" => "\103\x72\145\x61\164\x65"]); goto e7a0c; e7a0c: return $form; goto C01d0; C01d0: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto C144f; C144f: if (true === $form->isValid()) { goto E9ed2; } goto A865a; fecab: goto ba1c5; goto cb6c9; E9fe4: try { goto Dc267; F9f4a: $session->getFlashBag()->set("\163\x75\143\143\145\x73\x73", $this->translator->trans("\x53\x69\x74\145\40\x68\x61\x73\x20\x62\145\x65\x6e\x20\143\162\145\x61\164\x65\x64\56")); goto A3561; F8829: throw new \Exception(sprintf("\126\x68\157\163\x74\x20\x74\145\x6d\x70\154\141\164\x65\40\42\x25\x73\42\x20\156\157\164\40\x66\x6f\x75\x6e\x64\x2e", $vhostTemplateName)); goto Ccc20; E5726: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto cc94c; debda: return $response; goto Db6a5; A94cb: $eventData = ["\163\x69\164\145" => $domainName, "\x73\151\164\145\x55\163\x65\x72" => $siteUser, "\x70\x79\x74\150\157\x6e\x56\145\x72\x73\151\157\156" => $pythonVersion, "\160\x6f\x72\164" => $port]; goto b1931; C8ea9: $siteUserPassword = $form->get("\163\151\x74\145\x55\x73\x65\162\x50\x61\x73\x73\x77\x6f\162\x64")->getData(); goto b7961; b7961: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto E5726; b1931: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto F9f4a; cc94c: if (false === is_null($vhostTemplateEntity)) { goto F18cc; } goto F8829; f3bbf: $domainName = $form->get("\144\157\155\x61\x69\x6e\116\141\x6d\x65")->getData(); goto C3eb4; C689e: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto A94cb; Ccc20: goto D9bdb; goto affc2; df611: $siteUser = $form->get("\x73\x69\164\x65\x55\163\145\x72")->getData(); goto C8ea9; ab5ee: $port = $form->get("\160\157\162\x74")->getData(); goto df611; A3561: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\x69\x74\x65\163")); goto debda; Db6a5: D9bdb: goto D1ebf; Dc267: $session = $request->getSession(); goto f3bbf; Ac50a: $user = $this->getUser(); goto C689e; C3eb4: $pythonVersion = $form->get("\x70\x79\x74\x68\157\156\x56\x65\162\x73\151\157\156")->getData(); goto ab5ee; affc2: F18cc: goto Ac50a; D1ebf: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\x65\x72", $this->translator->trans("\101\x6e\x20\x65\x72\162\x6f\162\40\x68\141\x73\40\157\x63\x63\x75\162\x72\x65\x64\54\40\x65\162\x72\x6f\162\x20\155\145\x73\x73\x61\147\x65\72\40\45\145\x72\162\157\x72\115\x65\163\163\141\x67\145\45", ["\45\145\162\162\x6f\162\115\145\x73\163\x61\x67\145\45" => $e->getMessage()])); } goto df8fc; df8fc: ba1c5: goto B9dd5; cb6c9: E9ed2: goto E9fe4; A865a: $this->formErrors = $this->getErrorMessages($form); goto fecab; B9dd5: } public function newReverseProxy(Request $request) : Response { goto De610; b68da: F68b3: goto bbb5b; B16ae: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto eaa71; } goto f3af0; Dc208: return $response; goto b68da; Dde78: $response = $this->render("\106\162\157\x6e\164\x65\x6e\144\x2f\123\151\164\145\57\116\145\x77\x2f\x72\x65\166\145\x72\x73\x65\x2d\160\x72\x6f\170\171\x2e\150\x74\x6d\154\56\x74\167\151\147", ["\x75\163\145\162" => $user, "\x66\157\x72\155" => $form->createView(), "\x66\157\162\155\x45\162\x72\x6f\162\163" => $this->formErrors]); goto cf094; F4a4a: if (!(true === $form->isSubmitted())) { goto d2b67; } goto c8900; f3af0: $form->handleRequest($request); goto F4a4a; Adc11: return $response; goto ee2ca; Fa473: if (true === $hasPermissions) { goto E3a52; } goto a541b; c8900: $response = $this->handleReverseProxyForm($request, $form); goto dc723; dfce0: $form = $this->createReverseProxyForm(); goto B16ae; c7310: E3a52: goto B7c5a; F046b: eaa71: goto Dde78; d23e7: goto ad733; goto c7310; dc723: if (!(false === is_null($response))) { goto F68b3; } goto Dc208; De610: $hasPermissions = $this->hasPermissions(); goto Fa473; B7c5a: $user = $this->getUser(); goto dfce0; bbb5b: d2b67: goto F046b; a541b: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\151\x74\145\x73")); goto d23e7; cf094: ad733: goto Adc11; ee2ca: } private function createReverseProxyForm() : Form { goto dd9ee; dd9ee: $form = $this->createForm("\101\160\x70\134\x46\x6f\162\155\134\x53\151\164\145\116\145\x77\x52\145\x76\145\x72\163\x65\x50\x72\157\x78\x79\x54\171\160\145", [], ["\x61\x63\x74\151\157\x6e" => $this->generateUrl("\x63\x6c\x70\137\163\x69\164\x65\x5f\x72\x65\166\x65\162\163\145\x5f\x70\162\x6f\170\x79\x5f\x6e\x65\167"), "\155\x65\x74\x68\157\144" => "\120\117\x53\x54", "\141\x74\x74\162" => ["\151\144" => "\x6e\x65\167\55\162\145\166\x65\x72\163\145\55\160\162\157\x78\171\55\146\x6f\162\x6d"]]); goto e143d; bd62f: return $form; goto D6788; e143d: $form->add("\163\x75\142\155\x69\164", SubmitType::class, ["\141\x74\164\162" => ["\143\154\141\x73\x73" => "\142\164\x6e\40\x62\x74\156\x2d\x6c\147\x20\x62\164\156\55\x62\154\165\x65"], "\154\141\142\x65\154" => "\x43\x72\145\x61\164\x65"]); goto bd62f; D6788: } private function handleReverseProxyForm(Request $request, Form $form) { goto cb901; b1939: goto d1bbb; goto d1169; d1169: F4a57: goto e39f4; Bc6ea: d1bbb: goto B02da; cb901: if (true === $form->isValid()) { goto F4a57; } goto E5a7e; e39f4: try { goto fdf68; Eb74c: return $response; goto Ff4e6; Fe3d8: $user = $this->getUser(); goto fad50; fad50: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto Fa22c; f636c: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\164\145\163")); goto Eb74c; Ed852: $session->getFlashBag()->set("\163\x75\x63\x63\145\163\163", $this->translator->trans("\122\x65\x76\x65\162\x73\x65\x20\120\x72\x6f\170\171\x20\x68\x61\x73\40\x62\145\145\156\x20\143\162\x65\x61\164\x65\x64\56")); goto f636c; caed0: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto c97ac; a6c86: $siteUser = $form->get("\163\x69\164\145\125\x73\145\x72")->getData(); goto Cfd77; c3c80: $reverseProxyUrl = $form->get("\162\x65\166\x65\x72\x73\x65\x50\x72\157\170\x79\x55\162\154")->getData(); goto e6b31; Fa22c: $eventData = ["\x73\151\x74\x65" => $domainName, "\x73\151\164\145\x55\x73\145\162" => $siteUser, "\162\145\x76\x65\162\x73\145\120\x72\157\170\171\125\x72\x6c" => $reverseProxyUrl]; goto F9306; fdf68: $session = $request->getSession(); goto c0318; a88b3: f3e50: goto Fe3d8; Ff4e6: F13a3: goto e614b; daf08: goto F13a3; goto a88b3; c0318: $domainName = $form->get("\144\157\155\x61\151\x6e\x4e\141\x6d\145")->getData(); goto a6c86; F9306: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto Ed852; b9438: throw new \Exception(sprintf("\126\x68\x6f\x73\x74\x20\164\145\x6d\160\x6c\141\x74\145\40\x22\45\x73\x22\x20\x6e\157\x74\40\x66\x6f\x75\156\144\x2e", $vhostTemplateName)); goto daf08; e6b31: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto caed0; c97ac: if (false === is_null($vhostTemplateEntity)) { goto f3e50; } goto b9438; Cfd77: $siteUserPassword = $form->get("\163\x69\x74\145\125\163\x65\162\x50\x61\163\x73\167\x6f\x72\x64")->getData(); goto c3c80; e614b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\x65\162", $this->translator->trans("\101\x6e\x20\145\x72\162\x6f\162\40\150\x61\163\x20\x6f\x63\143\x75\162\162\145\144\54\x20\x65\162\162\x6f\162\x20\155\x65\163\163\x61\147\x65\x3a\x20\x25\145\162\x72\x6f\x72\x4d\145\163\163\x61\147\145\45", ["\x25\x65\162\x72\x6f\162\x4d\145\163\163\x61\x67\145\x25" => $e->getMessage()])); } goto Bc6ea; E5a7e: $this->formErrors = $this->getErrorMessages($form); goto b1939; B02da: } public function newNodejsSite(Request $request) : Response { goto c7f74; Eab0f: if (!(false === is_null($response))) { goto d1f69; } goto E0b70; Ee506: if (!(true === $request->isMethod("\x50\x4f\x53\124"))) { goto Ee11d; } goto e3b88; e5643: $response = $this->render("\x46\162\157\156\164\x65\156\x64\x2f\123\151\x74\145\x2f\116\145\x77\x2f\156\157\144\145\152\163\56\x68\164\x6d\x6c\56\164\x77\x69\147", ["\165\163\145\x72" => $user, "\146\x6f\x72\x6d" => $form->createView(), "\x66\x6f\x72\155\105\162\x72\x6f\x72\163" => $this->formErrors]); goto b0c4b; a7325: if (true === $hasPermissions) { goto Dccc1; } goto D8fd0; c7f74: $hasPermissions = $this->hasPermissions(); goto a7325; E6297: $response = $this->handleCreateNodejsSiteForm($request, $form); goto Eab0f; Dfa6c: Ee11d: goto e5643; b0c4b: a4eee: goto A250b; cc34b: $user = $this->getUser(); goto f4dad; Ada81: Dccc1: goto cc34b; E0b70: return $response; goto b3aa0; ed7c1: if (!(true === $form->isSubmitted())) { goto B2c06; } goto E6297; b3aa0: d1f69: goto E0944; f4dad: $nodejsSettings = new NodejsSettingsEntity(); goto ec6f8; A250b: return $response; goto B0c5f; e3b88: $form->handleRequest($request); goto ed7c1; Ce6d5: goto a4eee; goto Ada81; ec6f8: $form = $this->createNodejsSiteForm($nodejsSettings); goto Ee506; D8fd0: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\151\x74\x65\x73")); goto Ce6d5; E0944: B2c06: goto Dfa6c; B0c5f: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto E8671; E8671: $form = $this->createForm("\x41\160\160\x5c\106\157\162\x6d\134\x53\151\x74\145\116\145\x77\x4e\x6f\144\x65\x6a\163\x54\x79\160\145", $nodejsSettings, ["\x61\x63\x74\151\x6f\x6e" => $this->generateUrl("\143\x6c\x70\137\163\x69\x74\145\137\x6e\157\x64\x65\152\163\x5f\156\x65\167"), "\155\x65\164\x68\157\x64" => "\x50\117\x53\x54", "\x61\x74\164\162" => ["\x69\144" => "\x6e\145\167\x2d\156\157\144\x65\152\163\x2d\x73\151\164\x65\55\x66\x6f\162\155"]]); goto Cacff; Cacff: $form->add("\163\165\142\155\151\164", SubmitType::class, ["\141\x74\x74\162" => ["\x63\x6c\141\x73\163" => "\142\164\156\x20\x62\164\156\55\154\x67\x20\142\x74\x6e\55\142\x6c\165\x65"], "\x6c\x61\x62\x65\154" => "\103\162\145\141\164\x65"]); goto c5626; c5626: return $form; goto e96a3; e96a3: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto cce1f; dd955: try { goto a2767; f06d0: $eventData = ["\163\151\x74\145" => $domainName, "\163\151\164\145\x55\163\x65\x72" => $siteUser, "\156\x6f\x64\145\152\x73\x56\x65\162\x73\x69\x6f\156" => $nodejsVersion, "\x70\157\x72\164" => $port]; goto efe2b; b819b: $port = $form->get("\x70\x6f\x72\x74")->getData(); goto Aebb7; Ab3e8: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto F8f6f; F8f6f: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D9482; D9482: if (false === is_null($vhostTemplateEntity)) { goto Deec2; } goto Fd48c; af6be: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto f06d0; d96b8: Deec2: goto ab749; A6d93: $nodejsVersion = $form->get("\x6e\157\144\x65\152\x73\x56\x65\162\163\x69\157\x6e")->getData(); goto b819b; efe2b: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto A6f73; Eafcb: return $response; goto C7189; E0405: $domainName = $form->get("\x64\x6f\155\x61\x69\156\x4e\141\x6d\x65")->getData(); goto A6d93; d5663: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\151\164\145\163")); goto Eafcb; C7fa3: goto E797e; goto d96b8; ab749: $user = $this->getUser(); goto af6be; Fd48c: throw new \Exception(sprintf("\126\x68\157\163\x74\40\164\145\155\160\154\x61\x74\x65\x20\42\x25\x73\x22\x20\156\x6f\164\40\146\157\x75\156\x64\56", $vhostTemplateName)); goto C7fa3; A6f73: $session->getFlashBag()->set("\x73\x75\143\x63\x65\x73\163", $this->translator->trans("\x53\151\164\145\40\x68\141\163\40\142\x65\145\156\x20\143\x72\x65\141\x74\145\144\x2e")); goto d5663; a2767: $session = $request->getSession(); goto E0405; Aebb7: $siteUser = $form->get("\163\151\164\145\x55\163\x65\x72")->getData(); goto d2e6c; C7189: E797e: goto c0f08; d2e6c: $siteUserPassword = $form->get("\163\x69\x74\x65\x55\x73\x65\x72\x50\141\x73\x73\x77\157\x72\144")->getData(); goto Ab3e8; c0f08: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\145\x72", $this->translator->trans("\101\x6e\x20\145\162\162\157\162\x20\x68\141\x73\40\157\x63\143\x75\162\x72\x65\144\54\40\145\x72\162\157\162\40\155\x65\163\x73\x61\147\145\72\40\x25\145\162\x72\x6f\x72\115\x65\x73\x73\x61\147\x65\45", ["\45\145\162\x72\157\x72\115\145\163\x73\141\x67\145\45" => $e->getMessage()])); } goto Dd2f4; Ba1e4: $this->formErrors = $this->getErrorMessages($form); goto Edd1e; Edd1e: goto B8c0c; goto D7165; cce1f: if (true === $form->isValid()) { goto fa86d; } goto Ba1e4; Dd2f4: B8c0c: goto Cdd44; D7165: fa86d: goto dd955; Cdd44: } public function newStaticSite(Request $request) : Response { goto fb88c; aad2f: Cd4df: goto c2a75; d8c3f: goto f366a; goto A9181; fb88c: $hasPermissions = $this->hasPermissions(); goto Ac7a4; d4a14: $user = $this->getUser(); goto Da783; C4135: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\x69\x74\x65\163")); goto d8c3f; b0e05: f366a: goto eccb7; eccb7: return $response; goto bb063; c2a75: $response = $this->render("\x46\162\x6f\x6e\164\145\x6e\x64\57\123\x69\164\145\57\x4e\x65\x77\57\163\164\x61\164\151\x63\56\x68\164\155\154\x2e\x74\167\151\147", ["\165\x73\145\162" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\162\155\x45\x72\162\157\162\x73" => $this->formErrors]); goto b0e05; d97ab: c7377: goto aad2f; Cb931: ca066: goto d97ab; F4591: return $response; goto Cb931; ae5c4: if (!(false === is_null($response))) { goto ca066; } goto F4591; Efa8c: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto Cd4df; } goto D7bd1; A9181: A5402: goto d4a14; D7bd1: $form->handleRequest($request); goto E748e; Da783: $form = $this->createStaticSiteForm(); goto Efa8c; Dea9e: $response = $this->handleCreateStaticSiteForm($request, $form); goto ae5c4; Ac7a4: if (true === $hasPermissions) { goto A5402; } goto C4135; E748e: if (!(true === $form->isSubmitted())) { goto c7377; } goto Dea9e; bb063: } private function createStaticSiteForm() : Form { goto ea59a; ea59a: $form = $this->createForm("\101\160\160\x5c\x46\x6f\x72\155\134\123\151\164\x65\116\x65\167\x53\x74\x61\x74\x69\143\124\x79\160\x65", [], ["\x61\143\x74\151\157\x6e" => $this->generateUrl("\x63\154\x70\x5f\163\151\164\145\x5f\163\164\141\x74\x69\x63\137\x6e\x65\x77"), "\x6d\145\x74\150\157\144" => "\120\x4f\x53\x54", "\x61\164\x74\x72" => []]); goto C3406; a11d1: return $form; goto ca4ec; C3406: $form->add("\163\x75\x62\x6d\151\x74", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\x61\163\163" => "\x62\x74\x6e\40\x62\164\156\55\x6c\x67\x20\142\164\156\55\x62\154\x75\x65"], "\x6c\141\x62\145\x6c" => "\103\162\145\x61\164\x65"]); goto a11d1; ca4ec: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto Cffcd; D0e7d: C573d: goto Ae0ad; Cffcd: if (true === $form->isValid()) { goto C573d; } goto d47ad; d47ad: $this->formErrors = $this->getErrorMessages($form); goto De0b3; C2793: db586: goto Bea46; De0b3: goto db586; goto D0e7d; Ae0ad: try { goto d8799; B5356: goto c15e6; goto F8b6a; Af0f1: throw new \Exception(sprintf("\x56\x68\157\163\x74\x20\164\x65\155\160\154\x61\164\x65\40\x22\45\163\x22\40\156\157\164\40\x66\x6f\165\156\x64\56", $vhostTemplateName)); goto B5356; D7193: if (false === is_null($vhostTemplateEntity)) { goto afb09; } goto Af0f1; C0a99: $eventData = ["\x73\x69\164\145" => $domainName, "\x73\151\x74\145\x55\x73\145\162" => $siteUser]; goto Bbbda; f4cf7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D7193; a4f3c: $siteUserPassword = $form->get("\x73\151\164\145\x55\163\x65\x72\120\x61\163\163\167\157\x72\x64")->getData(); goto bd42a; c52ac: return $response; goto Cf3b3; Bbbda: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto c0b50; c22b5: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\x69\164\x65\x73")); goto c52ac; d8799: $session = $request->getSession(); goto ec114; c0b50: $session->getFlashBag()->set("\x73\165\143\x63\x65\163\163", $this->translator->trans("\x53\151\164\145\40\x68\141\x73\40\x62\x65\145\156\x20\x63\162\x65\141\x74\x65\x64\x2e")); goto c22b5; Cf3b3: c15e6: goto e3203; F8b6a: afb09: goto E8d65; ec114: $domainName = $form->get("\144\x6f\x6d\x61\151\x6e\x4e\x61\155\x65")->getData(); goto Bd691; bd42a: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto f4cf7; E8d65: $user = $this->getUser(); goto a705f; a705f: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto C0a99; Bd691: $siteUser = $form->get("\163\x69\164\145\125\x73\145\162")->getData(); goto a4f3c; e3203: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\162", $this->translator->trans("\101\156\x20\145\162\162\157\x72\x20\x68\x61\x73\40\157\143\143\165\162\x72\x65\x64\x2c\40\145\162\x72\x6f\x72\40\x6d\145\163\x73\x61\147\145\72\40\45\145\x72\x72\157\x72\x4d\x65\x73\x73\141\147\145\x25", ["\45\145\x72\162\157\x72\x4d\x65\163\163\141\x67\145\45" => $e->getMessage()])); } goto C2793; Bea46: } public function newPhpSite(Request $request) : Response { goto A4e46; F9e1a: if (!(true === $form->isSubmitted())) { goto fe9fb; } goto f8496; a5b25: return $response; goto bcf86; E41cb: ddc28: goto a5b25; A4e46: $hasPermissions = $this->hasPermissions(); goto e52d5; f5a17: dc19b: goto c5d54; a2d5d: $form->handleRequest($request); goto F9e1a; f8496: $response = $this->handleCreatePhpSiteForm($request, $form); goto a29f2; b4674: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\164\x65\163")); goto E43b2; c5d54: $response = $this->render("\x46\x72\x6f\x6e\164\x65\x6e\x64\57\x53\x69\x74\145\x2f\x4e\145\167\x2f\160\x68\160\x2e\x68\164\x6d\x6c\56\x74\167\x69\x67", ["\x75\x73\145\162" => $user, "\146\157\162\x6d" => $form->createView(), "\146\157\162\x6d\105\162\x72\x6f\x72\x73" => $this->formErrors]); goto E41cb; Cebf6: return $response; goto e407d; e407d: a50c6: goto aaf9c; E43b2: goto ddc28; goto E8bbe; b0835: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto dc19b; } goto a2d5d; E8af7: $form = $this->createPhpSiteForm(); goto b0835; Ecec1: $user = $this->getUser(); goto E8af7; a29f2: if (!(false === is_null($response))) { goto a50c6; } goto Cebf6; e52d5: if (true === $hasPermissions) { goto Ce570; } goto b4674; E8bbe: Ce570: goto Ecec1; aaf9c: fe9fb: goto f5a17; bcf86: } private function createPhpSiteForm() : Form { goto fa229; B334e: $form->add("\163\x75\142\x6d\151\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\x63\x6c\x61\163\163" => "\142\x74\156\40\x62\x74\156\55\154\x67\40\x62\164\x6e\55\x62\154\165\145"], "\154\141\x62\145\154" => "\x43\x72\145\x61\164\145"]); goto D4166; fa229: $form = $this->createForm("\101\160\160\x5c\x46\157\162\x6d\134\123\151\164\145\x4e\145\x77\120\x68\160\x54\x79\160\145", [], ["\141\x63\x74\151\157\x6e" => $this->generateUrl("\143\x6c\x70\137\x73\x69\164\145\137\160\x68\x70\x5f\156\145\167"), "\x6d\145\x74\x68\157\144" => "\120\117\x53\x54", "\x61\164\164\162" => []]); goto B334e; D4166: return $form; goto e1f1b; e1f1b: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto f0146; eaffd: goto Ef7da; goto C4848; a98f6: try { goto a948c; d9d17: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto A12b4; a948c: $session = $request->getSession(); goto bc3fe; Ab511: $domainName = $form->get("\144\157\x6d\x61\151\x6e\x4e\x61\x6d\145")->getData(); goto b400f; bff24: $user = $this->getUser(); goto a187b; E615c: $siteUserPassword = $form->get("\x73\151\164\x65\125\x73\145\162\120\141\163\x73\x77\157\x72\x64")->getData(); goto d9d17; a187b: $rootDirectory = $domainName; goto bdf13; B86c0: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\x74\x65\163")); goto cd78f; A12b4: if (false === is_null($vhostTemplateEntity)) { goto f8f86; } goto Be5c5; Daaa5: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a94ba; Ca241: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto B204d; } goto a57d7; bc9ae: $siteUser = $form->get("\x73\x69\164\x65\125\163\145\162")->getData(); goto E615c; bc3fe: $vhostTemplateName = $form->get("\141\160\x70\x6c\x69\143\x61\164\x69\x6f\x6e")->getData(); goto Ab511; a94ba: $eventData = ["\163\151\164\145" => $domainName, "\166\150\x6f\x73\x74\x54\145\x6d\x70\154\x61\164\x65\116\141\155\145" => $vhostTemplateName, "\x70\150\x70\126\x65\x72\x73\x69\x6f\x6e" => $phpVersion, "\163\x69\x74\x65\x55\163\145\x72" => $siteUser]; goto c913e; e3257: B204d: goto Daaa5; C83fc: $varnishCacheSettings = []; goto Ca241; cd78f: return $response; goto ea3d3; c913e: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto A6495; A6495: $session->getFlashBag()->set("\x73\165\143\x63\145\x73\x73", $this->translator->trans("\x53\151\164\x65\x20\x68\x61\163\40\142\145\145\x6e\x20\143\162\x65\141\164\x65\x64\56")); goto B86c0; e75f2: A8438: goto C83fc; f253d: f8f86: goto bff24; a57d7: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto e3257; Be5c5: throw new \Exception(sprintf("\x56\x68\157\163\164\40\x74\145\155\160\154\141\x74\145\40\x22\x25\x73\42\x20\156\x6f\164\x20\x66\157\165\156\x64\56", $vhostTemplateName)); goto fe13f; b400f: $phpVersion = $form->get("\x70\150\160\126\x65\x72\x73\151\x6f\x6e")->getData(); goto bc9ae; Cfaeb: $rootDirectory = sprintf("\45\x73\x2f\x25\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto e75f2; ea3d3: fb8c6: goto Bff58; fe13f: goto fb8c6; goto f253d; bdf13: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto A8438; } goto Cfaeb; Bff58: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\162", $this->translator->trans("\x41\156\x20\145\x72\162\157\x72\40\x68\x61\x73\x20\157\x63\x63\x75\162\x72\145\x64\x2c\x20\145\x72\x72\157\162\40\155\x65\x73\163\x61\147\145\72\x20\x25\145\162\x72\x6f\162\x4d\x65\x73\163\x61\147\x65\x25", ["\45\145\162\162\157\162\115\145\163\163\141\x67\x65\x25" => $e->getMessage()])); } goto f1ef6; f1ef6: Ef7da: goto bcbd7; C4848: A8f43: goto a98f6; e4f1c: $this->formErrors = $this->getErrorMessages($form); goto eaffd; f0146: if (true === $form->isValid()) { goto A8f43; } goto e4f1c; bcbd7: } public function newWordPressSite(Request $request) : Response { goto D2dbd; fc8bd: $form->handleRequest($request); goto Acd80; f709d: $response = $this->render("\x46\162\157\156\x74\x65\x6e\x64\x2f\123\151\164\145\57\x4e\145\x77\57\x77\x6f\x72\x64\x70\162\x65\163\163\x2e\x68\x74\x6d\154\56\164\x77\x69\x67", ["\x75\163\145\162" => $user, "\x66\x6f\x72\155" => $form->createView(), "\x66\157\x72\x6d\105\x72\162\157\162\x73" => $this->formErrors]); goto a4438; Fc9a7: return $response; goto C07f4; Fb5d6: B6842: goto Ec036; D2dbd: $hasPermissions = $this->hasPermissions(); goto Eaff4; Fed84: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\151\164\145\163")); goto a85a9; a4438: Ef55c: goto Fc9a7; a0d44: if (!(false === is_null($response))) { goto B4aed; } goto ea72f; ea72f: return $response; goto C6b65; a3eb3: A9ee0: goto f709d; a0656: $form = $this->createWordPressSiteForm(); goto d2ba7; Aa94f: Da74a: goto a3eb3; C6b65: B4aed: goto Aa94f; d2ba7: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto A9ee0; } goto fc8bd; a85a9: goto Ef55c; goto Fb5d6; Acd80: if (!(true === $form->isSubmitted())) { goto Da74a; } goto c4e90; Ec036: $user = $this->getUser(); goto a0656; c4e90: $response = $this->handleCreateWordPressSiteForm($request, $form); goto a0d44; Eaff4: if (true === $hasPermissions) { goto B6842; } goto Fed84; C07f4: } private function createWordPressSiteForm() : Form { goto b4c8d; F778c: $form->add("\163\x75\142\155\151\164", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\x6c\141\x73\163" => "\x62\164\x6e\40\x62\164\156\55\x6c\147\40\142\x74\156\55\x62\x6c\x75\x65"], "\154\141\142\x65\x6c" => "\x43\x72\x65\x61\164\145"]); goto c76cf; c76cf: return $form; goto caa29; b4c8d: $form = $this->createForm("\x41\160\160\x5c\x46\x6f\x72\x6d\x5c\123\x69\164\145\x4e\x65\x77\x57\157\x72\144\120\162\145\x73\163\x54\171\x70\145", [], ["\x61\x63\x74\151\x6f\x6e" => $this->generateUrl("\x63\x6c\160\x5f\163\x69\164\x65\x5f\x77\x6f\x72\144\x70\162\x65\163\x73\x5f\x6e\x65\x77"), "\155\x65\x74\x68\x6f\x64" => "\120\117\x53\x54", "\141\164\164\x72" => ["\x69\144" => "\x6e\145\167\x2d\167\157\x72\x64\x70\162\x65\163\x73\55\x73\x69\x74\x65\x2d\146\x6f\x72\x6d"]]); goto F778c; caa29: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto bf4eb; B1807: $this->formErrors = $this->getErrorMessages($form); goto c736a; bf4eb: if (true === $form->isValid()) { goto e3e4b; } goto B1807; D4111: b286e: goto Fa2fd; a56cb: try { goto d10b3; d133d: $adminEmail = $form->get("\141\144\x6d\151\156\105\x6d\x61\151\154")->getData(); goto Fbe12; bb8e0: $databaseEntity = $this->databaseEntityManager->createEntity(); goto da66e; b5608: $databaseUserEntity->setDatabase($databaseEntity); goto E9310; B462c: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto ce65d; df1f7: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto b5608; e9185: $session->set("\163\x69\x74\145\103\x72\145\144\145\156\x74\x69\x61\154\x73", $siteCredentials); goto E653f; E653f: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\151\164\x65\x55\x73\145\162" => $siteUser]; goto Df374; bacab: $title = $form->get("\163\151\x74\145\124\151\x74\x6c\145")->getData(); goto a3957; B90d3: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto c0cd0; D40f5: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto f1fbe; E0b8d: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto Fa563; } goto c0c0e; E5c2f: D29e3: goto e9185; a2bcb: $domainName = $form->get("\x64\x6f\x6d\141\151\156\x4e\x61\155\x65")->getData(); goto c5480; c7ac2: if (!(false === is_null($siteEntity))) { goto D29e3; } goto a7373; dd68d: $this->siteEntityManager->updateEntity($siteEntity); goto B90d3; B565f: $databaseManager->createUser($databaseUserEntity); goto dd68d; a7373: $databaseName = $this->getUniqueDatabaseName($generatedName); goto bf361; Ede4c: $adminPassword = $form->get("\x61\144\x6d\151\x6e\x50\141\x73\163\x77\x6f\162\144")->getData(); goto d133d; E9310: $databaseEntity->addUser($databaseUserEntity); goto d0db1; caa72: return $response; goto e9226; da66e: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto f3ecf; fde0c: $siteCredentials["\127\157\x72\x64\x50\162\x65\163\163"] = [$this->translator->trans("\x41\144\x6d\x69\156\40\105\55\115\141\151\154") => $adminEmail, $this->translator->trans("\x41\x64\x6d\x69\156\x20\x55\163\x65\162\40\116\x61\x6d\145") => $adminUserName, $this->translator->trans("\101\x64\x6d\x69\x6e\40\x50\141\163\x73\x77\x6f\162\x64") => $adminPassword, $this->translator->trans("\101\x64\x6d\x69\x6e\40\x55\x72\x6c") => sprintf("\150\x74\164\x70\163\72\x2f\57\x25\163\57\x77\x70\x2d\x61\x64\x6d\x69\x6e\57", rtrim($domainName, "\x2f"))]; goto E5c2f; dcc5a: $siteUserPassword = $form->get("\x73\151\164\145\125\x73\x65\x72\x50\141\163\163\x77\x6f\x72\x64")->getData(); goto A4bdb; F1138: $instance = $request->attributes->get("\151\x6e\x73\164\141\156\143\x65"); goto cc94a; b3244: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto bb8e0; b5b3c: $databaseUserEntity->setUserName($databaseUserName); goto c5bdd; a5ac5: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto f435c; ff657: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto F1138; c5480: $generatedName = $this->generateNameFromDomainName($domainName); goto Ef04a; c0cd0: $siteCredentials[$this->translator->trans("\104\141\x74\x61\142\141\x73\x65")] = [$this->translator->trans("\x48\x6f\163\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\157\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\141\164\141\142\141\x73\145\40\x4e\141\x6d\145") => $databaseName, $this->translator->trans("\x44\141\164\x61\x62\x61\x73\145\40\x55\163\x65\162\40\x4e\x61\155\x65") => $databaseUserName, $this->translator->trans("\104\x61\x74\x61\142\x61\x73\145\40\125\x73\x65\x72\40\x50\x61\x73\x73\x77\157\x72\144") => $databaseUserPassword]; goto fde0c; f1fbe: $databaseManager->createDatabase($databaseEntity); goto B565f; c5bdd: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto df1f7; f435c: $url = sprintf("\150\x74\x74\160\x73\72\57\x2f\45\163", $siteEntity->getDomainName()); goto bacab; cc94a: $siteCredentials = [$this->translator->trans("\x53\x69\x74\145") => [$this->translator->trans("\x49\x50\40\x41\144\144\x72\x65\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\157\155\x61\151\x6e\40\x4e\x61\x6d\x65") => sprintf("\150\x74\164\160\163\x3a\x2f\57\45\x73", $domainName), $this->translator->trans("\123\x69\x74\145\x20\x55\x73\x65\x72") => $siteUser, $this->translator->trans("\x50\x61\x73\163\x77\157\162\x64") => $siteUserPassword]]; goto c7ac2; ce65d: $varnishCacheSettings = []; goto E0b8d; A4bdb: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto B462c; E12ac: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\163\151\164\x65\137\x77\157\162\x64\160\162\145\x73\x73\137\151\x6e\x73\164\141\x6c\x6c\x65\144")); goto caa72; C25a2: Fa563: goto b71c5; dda86: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto b5b3c; Fbe12: $isMultiSite = $form->get("\x6d\165\x6c\x74\x69\x53\151\164\145")->getData(); goto b3244; Ef04a: $siteUser = $form->get("\163\151\x74\x65\x55\163\x65\x72")->getData(); goto dcc5a; d10b3: $user = $this->getUser(); goto E4e73; f3ecf: $databaseEntity->setName($databaseName); goto e7226; Df374: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto E12ac; e7226: $databaseEntity->setSite($siteEntity); goto dda86; bf361: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto a5ac5; b71c5: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto ff657; E4e73: $session = $request->getSession(); goto a2bcb; c0c0e: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto C25a2; d0db1: $siteEntity->addDatabase($databaseEntity); goto D40f5; a3957: $adminUserName = $form->get("\x61\144\155\x69\x6e\125\163\x65\162\x4e\141\155\145")->getData(); goto Ede4c; e9226: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\145\162", $this->translator->trans("\101\x6e\x20\145\x72\162\157\x72\40\150\141\x73\40\157\143\143\x75\162\x72\x65\144\x2c\40\145\x72\x72\157\162\x20\155\145\163\163\x61\x67\145\x3a\x20\x25\145\x72\162\x6f\x72\x4d\145\163\163\141\147\x65\x25", ["\x25\x65\162\x72\x6f\x72\x4d\145\163\x73\x61\x67\145\45" => $e->getMessage()])); } goto D4111; c736a: goto b286e; goto Bf116; Bf116: e3e4b: goto a56cb; Fa2fd: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto B1246; B1246: $databaseHost = sprintf("\45\163\72\45\x73", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto Ceec6; dc511: $wordPressInstaller = new WordPressInstaller($siteEntity); goto fd030; d7c9e: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\x6c\x75\145"], $config["\162\x61\167"]); c0494: } goto ff126; Fee7b: Aef47: goto e88cc; B111e: $this->wordPressMultiSiteConfigValues["\104\117\115\x41\x49\116\x5f\103\125\122\x52\x45\116\x54\x5f\123\111\124\105"]["\166\141\154\x75\x65"] = $siteEntity->getDomainName(); goto d5f20; ddc7d: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto d7c9e; e88cc: $wordPressInstaller->resetPermissions(); goto F36d7; d5f20: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\x6c\x75\145"], $config["\x72\x61\x77"]); f9e9f: } goto c5b67; f357c: if (!(true === $isMultiSite)) { goto Aef47; } goto B111e; cfba6: $databaseUserName = $databaseUserEntity->getUserName(); goto C9661; fd030: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Fadec; c5b67: ec06b: goto Fee7b; C9661: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto dc511; ff126: a5a39: goto f357c; Ceec6: $databaseName = $databaseEntity->getName(); goto cfba6; Fadec: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto ddc7d; F36d7: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto d4043; d25de: $phpSiteCreator->createPhpFpmPool(); goto F75c6; Be67a: $phpSettingsEntity = new PhpSettingsEntity(); goto c13a5; aa8c0: $constraintViolationList->addAll($phpSettingsConstraints); goto c33ad; bc925: $certificateEntity->setCertificate($selfSignedCertificate); goto Bc6be; D83a5: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto E7c74; C45f9: $vhostTemplate = new PhpVhostTemplate($phpSite); goto B459a; a9473: $this->siteEntityManager->updateEntity($siteEntity); goto Bb456; ab78e: $phpSiteCreator->createUser(); goto A41e3; e4020: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto ead63; } goto Ada9d; ef0a1: if (!(true === is_null($subdomain))) { goto b5530; } goto ed90c; ccf93: $rsaKeyGenerator = new RsaKeyGenerator(); goto A7cad; Bb456: return $siteEntity; goto Bba11; afc69: $siteEntity->setUserPassword($siteUserPassword); goto A0b45; E3fa8: $siteEntity->setVhostTemplate($vhostTemplate); goto Be67a; Ccb7f: $certificateEntity->setCsr($csr); goto bbaab; F1f20: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto df226; ed90c: $subjectAlternativeNames[] = sprintf("\x77\x77\167\x2e\x25\x73", $domainName); goto a9934; C2fab: $phpSite->setPhpSettings($phpSettingsEntity); goto C9b99; c80b6: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Bb5e2; Edbde: $phpSiteCreator->reloadNginxService(); goto ed6b8; d4043: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto c3833; fdd71: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto ba099; ffd54: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto D83a5; A41e3: $phpSiteCreator->createRootDirectory(); goto a8539; c33ad: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e166c; e25be: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto Cb5d0; } goto B80b5; e8d40: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A4274; C9b99: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Fb66d; B80b5: $subjectAlternativeNames[] = $registrableDomain; goto cc4f6; e3e7f: $phpSite = new PhpSite(); goto e373a; D0590: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto fde4b; } goto f1aad; f8e2b: $siteEntity->setUser($siteUser); goto afc69; c3ddd: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\56\56\x2f\56\56\x2f\162\x65\163\x6f\x75\162\143\x65\x73\x2f\156\147\x69\156\170\57\x76\x68\x6f\163\x74\137\164\145\x6d\x70\154\x61\164\145\57\162\x65\144\151\162\145\x63\164"); goto A62b3; df226: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto a9473; Fadf0: $csr = $csrGenerator->generate(); goto B17ff; d1b54: $phpSite->setDomainName($domainName); goto bef36; cc4f6: Cb5d0: goto fdd71; a8539: $phpSiteCreator->createLogrotateFile(); goto A2686; B86fa: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto C87c2; Fa272: $constraintViolationList->addAll($siteConstraints); goto aa8c0; C0f0e: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c80b6; B459a: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto af485; Ca217: ead63: goto E3fa8; b2ebf: Db69b: goto C13a5; fa1f6: $phpSettingsEntity->setPhpVersion($phpVersion); goto fb5c9; af485: $vhostTemplate->resetProcessors(); goto C9eee; ed6b8: $phpSiteCreator->resetPermissions(); goto C45f9; e8b58: if (!(true === $varnishCache)) { goto D929c; } goto B4d4a; d32f0: fde4b: goto b5384; C13a5: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\x2f\x2e\x2e\x2f\x72\x65\x73\x6f\x75\x72\143\145\x73\x2f\x6e\147\151\x6e\x78\57\166\150\x6f\163\164\x5f\164\145\x6d\x70\154\141\164\145\x2f\x72\145\x64\x69\x72\145\x63\164\55\x68\x74\x74\160\63"); goto Cc8c7; Ada9d: if (true === isset($_ENV["\x41\120\120\137\x48\x54\124\120\x33"]) && "\x74\x72\165\x65" === $_ENV["\101\x50\120\x5f\x48\124\x54\120\x33"]) { goto Db69b; } goto c3ddd; c4243: A23a7: goto Ca217; fc3a4: $phpSiteCreator->createNginxVhost(); goto Edbde; A6267: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto ffd54; B099a: if (!(false === empty($varnishCache))) { goto Dff7e; } goto a4e1d; C48b9: $siteEntity->setDomainName($domainName); goto f8e2b; c6e0f: $phpSite->setSubdomain($subdomain); goto Fb0ab; F75c6: $phpSiteCreator->reloadPhpFpmService(); goto e8b58; A4274: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C0f0e; e373a: $phpSite->setUser($siteEntity->getUser()); goto Edc75; bfd75: $phpSiteCreator->createPrivateKeyAndCertificate(); goto d25de; a4dd8: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto D0590; e81a6: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D7e25; bef36: $phpSite->setRegistrableDomain($registrableDomain); goto c6e0f; b5384: $certificateEntity = $this->certificateEntityManager->createEntity(); goto b3bd8; ba888: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ccb7f; Fb66d: $phpSiteCreator = new PhpSiteCreator($phpSite); goto ab78e; Bb5e2: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto e81a6; Cc8c7: a9486: goto Dd781; B4d4a: $phpSite->setVarnishCache(true); goto ea265; c60c4: Dff7e: goto e4020; Fb0ab: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto A5374; Bc6be: $siteEntity->setCertificate($certificateEntity); goto e3e7f; ce648: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto c4243; c13a5: $siteEntity->setPhpSettings($phpSettingsEntity); goto fa1f6; D7e25: $siteEntity = $this->siteEntityManager->createEntity(); goto fb10d; A0b45: $siteEntity->setRootDirectory($rootDirectory); goto B099a; C87c2: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Bed4c; E7c74: D929c: goto fc3a4; fb10d: $siteEntity->setType(SiteEntity::TYPE_PHP); goto C48b9; a4e1d: $siteEntity->setVarnishCache(true); goto c60c4; fe6e1: $subjectAlternativeNames = []; goto ef0a1; C9eee: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B86fa; ea265: $defaultVarnishCacheSettings = ["\x65\156\x61\142\x6c\x65\144" => false, "\x73\x65\x72\166\x65\162" => self::VARNISH_CACHE_SERVER, "\x63\141\143\150\x65\x54\141\x67\x50\162\x65\146\151\x78" => substr(md5(time()), 0, 4)]; goto A6267; A62b3: goto a9486; goto b2ebf; A5374: $phpSite->setCertificate($certificateEntity); goto C2fab; Dd781: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto db8b5; A2686: $phpSiteCreator->createIndexPhp(); goto bfd75; f1aad: $constraintViolationList = new ConstraintViolationList(); goto Fa272; ba099: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Fadf0; a9934: b5530: goto e25be; B17ff: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto fd1be; Bed4c: $vhostTemplate->build(); goto F1f20; Acc05: $siteConstraints = $this->validator->validate($siteEntity); goto a4dd8; bbaab: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto bc925; A7cad: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto fe6e1; e166c: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto d32f0; fd1be: $certificateEntity->setDefaultCertificate(true); goto ba888; b3bd8: $certificateEntity->setSite($siteEntity); goto ccf93; Edc75: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto d1b54; db8b5: if (!(false === empty($redirectionVhostTemplate))) { goto A23a7; } goto ce648; c3833: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\x2f"); goto e8d40; fb5c9: $phpSettingsEntity->setSite($siteEntity); goto Acc05; Bba11: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto fab3d; e52bf: $siteEntity->setRootDirectory($domainName); goto bb124; E41dd: $vhostTemplate->build(); goto c9838; B839b: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto a9211; C6bbe: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto c05e5; B0b4d: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto cf4b8; E9a54: a286c: goto B545e; de96a: $nodejsSiteCreator->createNvmDirectory(); goto f60ca; B545e: $siteEntity->setVhostTemplate($vhostTemplate); goto c153c; bb124: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto a286c; } goto a3d60; Daee4: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c501b; F147c: $nodejsSite = new NodejsSite(); goto c1397; C1fa0: $nodejsSite->setDomainName($domainName); goto D07e4; c1397: $nodejsSite->setUser($siteEntity->getUser()); goto dff70; B306e: $certificateEntity->setCsr($csr); goto B0b4d; fab3d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto C4a34; B3e6c: E1ca0: goto E9a54; A10d1: $constraintViolationList->addAll($siteConstraints); goto Cd307; B2949: return $siteEntity; goto A71ac; Dd220: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B306e; C4a34: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto db0cc; B9100: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F6d7b; D8c10: goto ce535; goto Fa608; c9838: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto c93ab; A38d7: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E41dd; Cd307: $constraintViolationList->addAll($nodejsSettingsConstraints); goto B839b; C4131: $siteEntity->setUserPassword($siteUserPassword); goto e52bf; C33db: $nodejsSiteCreator->createRootDirectory(); goto C2963; f3630: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto fd56c; c784d: $siteEntity->setCertificate($certificateEntity); goto F147c; c9ded: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto A38d7; C2963: $nodejsSiteCreator->createLogrotateFile(); goto de96a; cf4b8: $certificateEntity->setCertificate($selfSignedCertificate); goto c784d; B48e2: $siteEntity = $this->siteEntityManager->createEntity(); goto Fef48; adbb8: $nodejsSiteCreator->reloadNginxService(); goto ef50a; Fa608: d48e7: goto b6f31; Ed0f5: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto ee5e3; C7919: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\163", $domainName); goto Bb1ad; B1692: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto E240e; E240e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto B48e2; c153c: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto A967f; E46df: $nodejsSiteCreator->createUser(); goto C33db; E1e3e: $subjectAlternativeNames[] = $registrableDomain; goto Cd3b4; db0cc: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ce51c; a02b5: $certificateEntity->setSite($siteEntity); goto b9c52; dff70: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto C1fa0; Ce59d: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E439b; Adf41: $nodejsSite->setSubdomain($subdomain); goto ad60f; F3782: $nodejsSite->setCertificate($certificateEntity); goto db719; e87ff: if (!(false === empty($redirectionVhostTemplate))) { goto E1ca0; } goto F4bd0; A7306: $csr = $csrGenerator->generate(); goto Dd085; C1e58: $certificateEntity = $this->certificateEntityManager->createEntity(); goto a02b5; F4bd0: $vhostTemplate = sprintf("\45\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto B3e6c; aa66c: B7911: goto C1e58; a7763: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto c9ded; D07e4: $nodejsSite->setRegistrableDomain($registrableDomain); goto Adf41; Bb1ad: a14b8: goto ca018; Cd3b4: E8070: goto Ce59d; Ea10a: $this->siteEntityManager->updateEntity($siteEntity); goto B2949; fd56c: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto B7911; } goto d9799; F6d7b: $vhostTemplate->resetProcessors(); goto a7763; E439b: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto A7306; f482d: $certificateEntity->setDefaultCertificate(true); goto Dd220; Dd085: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f482d; d3181: if (!(true === is_null($subdomain))) { goto a14b8; } goto C7919; d9799: $constraintViolationList = new ConstraintViolationList(); goto A10d1; f60ca: $nodejsSiteCreator->installNodejs(); goto Ed0f5; Abfac: $subjectAlternativeNames = []; goto d3181; b9c52: $rsaKeyGenerator = new RsaKeyGenerator(); goto b55cf; a3d60: if (true === isset($_ENV["\101\x50\x50\x5f\110\124\x54\x50\63"]) && "\x74\162\165\145" === $_ENV["\x41\120\120\x5f\110\x54\x54\120\63"]) { goto d48e7; } goto Cba06; ca018: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto E8070; } goto E1e3e; eb7ae: $siteConstraints = $this->validator->validate($siteEntity); goto f3630; b55cf: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Abfac; b3a01: ce535: goto f257d; c93ab: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ea10a; C7e6e: $siteEntity->setUser($siteUser); goto C4131; f257d: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto e87ff; Cba06: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\56\57\x2e\x2e\57\162\145\x73\x6f\x75\x72\143\145\163\57\156\147\x69\x6e\170\x2f\166\x68\157\163\164\137\164\145\155\160\x6c\x61\164\145\57\162\x65\144\151\162\x65\x63\x74"); goto D8c10; ee5e3: $nodejsSiteCreator->createNginxVhost(); goto adbb8; ce51c: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B1692; fc203: $siteEntity->setDomainName($domainName); goto C7e6e; a9211: throw new \Exception(implode("\73\x20", $errorMessages)); goto aa66c; Ced14: $nodejsSettingsEntity->setSite($siteEntity); goto eb7ae; ad60f: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto F3782; A967f: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto C6bbe; db719: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto Daee4; Fef48: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto fc203; ef50a: $nodejsSiteCreator->resetPermissions(); goto d8d2f; c501b: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto E46df; c05e5: $nodejsSettingsEntity->setPort($port); goto Ced14; b6f31: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\56\57\x2e\x2e\57\162\x65\x73\157\x75\162\x63\x65\x73\x2f\x6e\x67\151\156\170\57\166\x68\x6f\163\164\137\164\x65\x6d\160\154\x61\x74\145\57\x72\145\144\x69\162\x65\x63\x74\x2d\150\x74\x74\x70\63"); goto b3a01; d8d2f: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto B9100; A71ac: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto a138b; d9e07: E4c26: goto Af4a8; Fc138: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto B04af; Edf7d: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto d701b; d4c64: $constraintViolationList->addAll($pythonSettingsConstraints); goto B653c; Fcefc: $siteEntity->setRootDirectory($domainName); goto C4941; D054d: $pythonSiteCreator->createRootDirectory(); goto F0d9f; D8f61: $pythonSiteCreator->reloadNginxService(); goto C345a; dc486: $siteEntity->setPythonSettings($pythonSettingsEntity); goto E3882; bd302: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto A6a1f; ff585: $pythonSite = new PythonSite(); goto D416d; f0914: return $siteEntity; goto Fd716; B653c: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto d491f; e96c6: $pythonSettingsEntity->setSite($siteEntity); goto E9966; fdb73: $pythonSettingsEntity->setPort($port); goto e96c6; C4941: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto Fc69d; } goto Cd5eb; b10ce: $csr = $csrGenerator->generate(); goto Eb3e0; f6077: $subjectAlternativeNames[] = $registrableDomain; goto F0c19; d491f: throw new \Exception(implode("\73\x20", $errorMessages)); goto d9e07; A7138: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto b30ae; d4a42: $pythonSite->setPythonSettings($pythonSettingsEntity); goto A7138; C621b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\57\56\56\x2f\x72\x65\163\157\165\x72\143\x65\163\x2f\156\147\151\156\x78\57\166\x68\157\163\x74\137\x74\x65\x6d\x70\154\x61\x74\145\57\162\x65\x64\151\162\145\x63\164"); goto f9dce; e80a4: $siteEntity->setCertificate($certificateEntity); goto ff585; B04af: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto A840f; c7e9b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\x2e\56\57\162\145\163\157\165\x72\143\x65\x73\x2f\156\x67\151\x6e\170\x2f\x76\150\x6f\163\164\137\x74\x65\155\x70\x6c\141\164\x65\x2f\x72\145\144\x69\x72\145\143\x74\55\x68\164\164\x70\63"); goto Db5be; b30ae: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto f5b6b; e3236: $certificateEntity->setCsr($csr); goto F84ae; Db5be: Bf661: goto E57b1; f2cf7: $subjectAlternativeNames = []; goto F6240; e7e3f: $pythonSite->setRegistrableDomain($registrableDomain); goto Bc5be; F0c19: D3c38: goto E5c58; a138b: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b763e; Eb3e0: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto d25a2; D5681: $subjectAlternativeNames[] = sprintf("\x77\167\167\56\45\x73", $domainName); goto D87f6; f5b6b: $pythonSiteCreator->createUser(); goto D054d; Af4a8: $certificateEntity = $this->certificateEntityManager->createEntity(); goto D1492; C345a: $pythonSiteCreator->resetPermissions(); goto d7fe8; Df016: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f0914; ef430: $pythonSiteCreator->createNginxVhost(); goto D8f61; c55fd: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ebe31; E47a7: $vhostTemplate = sprintf("\x25\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto E930f; E2b02: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto D3c38; } goto f6077; E5c58: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ca9cd; b5c73: $siteEntity->setDomainName($domainName); goto b62c7; E0a2d: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto e3236; D416d: $pythonSite->setUser($siteEntity->getUser()); goto A91a9; f2983: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto f2cf7; Cd5eb: if (true === isset($_ENV["\x41\x50\x50\137\110\124\124\x50\x33"]) && "\164\x72\165\x65" === $_ENV["\101\120\120\137\110\124\x54\120\63"]) { goto Cf61a; } goto C621b; E930f: f45fb: goto bf50b; F6240: if (!(true === is_null($subdomain))) { goto F0540; } goto D5681; A91a9: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto c85dc; d701b: $pythonSite->setCertificate($certificateEntity); goto d4a42; cf8aa: $siteEntity->setVhostTemplate($vhostTemplate); goto a62db; F3502: $pythonSiteCreator->writePythonVersionFile(); goto e65da; F84ae: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Fa780; d25a2: $certificateEntity->setDefaultCertificate(true); goto E0a2d; a62db: $pythonSettingsEntity = new PythonSettingsEntity(); goto dc486; e65da: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto ef430; E57b1: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b026f; A840f: $vhostTemplate->build(); goto bd302; E96e8: $constraintViolationList->addAll($siteConstraints); goto d4c64; c85dc: $pythonSite->setDomainName($domainName); goto e7e3f; D0d0f: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c55fd; d7fe8: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto b7121; D87f6: F0540: goto E2b02; f9dce: goto Bf661; goto D706d; ca80a: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Fc138; Fa780: $certificateEntity->setCertificate($selfSignedCertificate); goto e80a4; b763e: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D0d0f; D706d: Cf61a: goto c7e9b; Ca9cd: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto b10ce; E9966: $siteConstraints = $this->validator->validate($siteEntity); goto d7acb; Dfa6a: $siteEntity->setUserPassword($siteUserPassword); goto Fcefc; ebe31: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto C8c77; d7acb: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto Ed14b; C8c77: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ca421; D1492: $certificateEntity->setSite($siteEntity); goto A567e; A6a1f: $this->siteEntityManager->updateEntity($siteEntity); goto Df016; A567e: $rsaKeyGenerator = new RsaKeyGenerator(); goto f2983; F0d9f: $pythonSiteCreator->createLogrotateFile(); goto F3502; b7121: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto feff8; Ed14b: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto E4c26; } goto ee926; b026f: if (!(false === empty($redirectionVhostTemplate))) { goto f45fb; } goto E47a7; feff8: $vhostTemplate->resetProcessors(); goto ca80a; b62c7: $siteEntity->setUser($siteUser); goto Dfa6a; ee926: $constraintViolationList = new ConstraintViolationList(); goto E96e8; e10af: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto b5c73; Bc5be: $pythonSite->setSubdomain($subdomain); goto Edf7d; E3882: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto fdb73; ca421: $siteEntity = $this->siteEntityManager->createEntity(); goto e10af; bf50b: Fc69d: goto cf8aa; Fd716: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto B8882; A6399: $staticSite->setSubdomain($subdomain); goto F7b06; e6c5b: $subjectAlternativeNames = []; goto f62f8; c8181: $siteConstraints = $this->validator->validate($siteEntity); goto Ff200; baaf7: throw new \Exception(implode("\x3b\40", $errorMessages)); goto a7cbb; b2216: $subjectAlternativeNames[] = $registrableDomain; goto Ae9a5; b3235: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto c6503; E4086: $rsaKeyGenerator = new RsaKeyGenerator(); goto F8b53; Bbdcb: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Aef73; b6eef: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto A8e54; ac085: $vhostTemplate = new StaticVhostTemplate($staticSite); goto edf8e; Ee5c0: $staticSiteCreator->createUser(); goto C1473; B735f: $staticSiteCreator->createLogrotateFile(); goto A3f31; a7cbb: D5ed2: goto eb842; Ff200: if (!count($siteConstraints)) { goto D5ed2; } goto F62e8; Aef73: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto A7508; ff115: $staticSiteCreator->createNginxVhost(); goto B4711; D7a99: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto cf3e4; b3873: $certificateEntity->setCsr($csr); goto b8f99; f87f7: B068e: goto D00f5; Dcc35: e0cdb: goto f87f7; b8f7d: $siteEntity->setCertificate($certificateEntity); goto F49bb; B8290: $constraintViolationList->addAll($siteConstraints); goto Fd53f; bd739: $certificateEntity->setSite($siteEntity); goto E4086; cf3e4: $staticSite->setDomainName($domainName); goto c741b; c6503: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto ecc2f; A3f31: $staticSiteCreator->createIndexHtml(); goto F372d; c741b: $staticSite->setRegistrableDomain($registrableDomain); goto A6399; B8882: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b034d; e96c8: $certificateEntity->setCertificate($selfSignedCertificate); goto b8f7d; E9680: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ebb53; a6781: goto C1ae2; goto Dfc06; ba504: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto A9ea6; d3f9e: $staticSiteCreator->resetPermissions(); goto ac085; A8e54: $siteEntity->setDomainName($domainName); goto A1f9c; C1531: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\x2e\x2f\56\x2e\57\x72\145\x73\x6f\165\162\x63\145\163\x2f\x6e\x67\151\x6e\170\x2f\166\150\157\x73\164\137\x74\145\x6d\160\154\141\x74\145\x2f\162\x65\144\x69\x72\145\x63\x74"); goto a6781; Ab791: $siteEntity->setRootDirectory($domainName); goto C1f85; B4711: $staticSiteCreator->reloadNginxService(); goto d3f9e; ec720: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto e6cc4; } goto b2216; f62f8: if (!(true === is_null($subdomain))) { goto C505a; } goto F9199; F62e8: $constraintViolationList = new ConstraintViolationList(); goto B8290; F372d: $staticSiteCreator->createPrivateKeyAndCertificate(); goto ff115; edf8e: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F5111; E4440: if (!(false === empty($redirectionVhostTemplate))) { goto e0cdb; } goto d01f4; F5111: $vhostTemplate->resetProcessors(); goto f8b51; da961: return $siteEntity; goto Cacf3; C1f85: if (!(true === is_null($subdomain) || "\167\x77\x77" == $subdomain)) { goto B068e; } goto Be423; E6588: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Bbe0f; C1473: $staticSiteCreator->createRootDirectory(); goto B735f; F8b53: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto e6c5b; b0aa6: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto d1762; eb842: $certificateEntity = $this->certificateEntityManager->createEntity(); goto bd739; D00f5: $siteEntity->setVhostTemplate($vhostTemplate); goto c8181; F49bb: $staticSite = new StaticSite(); goto a2d87; A4d70: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto E6588; b034d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto d395a; d1762: $staticSiteCreator = new StaticSiteCreator($staticSite); goto Ee5c0; C244f: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E4440; f8b51: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Bbdcb; d395a: $subdomain = $resolvedDomainName->subDomain()->toString(); goto C87c1; b8f99: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e96c8; E53ed: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\x2e\x2f\x2e\56\x2f\x72\145\x73\x6f\x75\x72\143\x65\163\x2f\156\147\x69\x6e\170\x2f\166\x68\x6f\163\164\137\164\145\x6d\160\154\141\164\x65\57\x72\145\144\x69\x72\145\143\164\55\150\164\164\160\63"); goto a9f18; F9199: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\45\163", $domainName); goto Fb5be; A9ea6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto b85a3; a9f18: C1ae2: goto C244f; C87c1: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A4d70; ebb53: $certificateEntity->setDefaultCertificate(true); goto cd72e; Ae9a5: e6cc4: goto b3235; Fd53f: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto baaf7; Dfc06: C05d0: goto E53ed; E7a8d: $staticSite->setCertificate($certificateEntity); goto b0aa6; ecc2f: $csr = $csrGenerator->generate(); goto E9680; D18f5: $siteEntity->setUserPassword($siteUserPassword); goto Ab791; Bbe0f: $siteEntity = $this->siteEntityManager->createEntity(); goto b6eef; d01f4: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto Dcc35; F7b06: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto E7a8d; a2d87: $staticSite->setUser($siteEntity->getUser()); goto D7a99; cd72e: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto b3873; Be423: if (true === isset($_ENV["\x41\120\x50\137\x48\x54\x54\x50\63"]) && "\164\x72\x75\x65" === $_ENV["\101\x50\120\137\110\124\x54\x50\63"]) { goto C05d0; } goto C1531; b85a3: $this->siteEntityManager->updateEntity($siteEntity); goto da961; Fb5be: C505a: goto ec720; A1f9c: $siteEntity->setUser($siteUser); goto D18f5; A7508: $vhostTemplate->build(); goto ba504; Cacf3: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto C556c; ba92d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto d6798; d42c0: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto e7bb2; Faa5a: $subjectAlternativeNames[] = $registrableDomain; goto Dbb45; a252f: $reversProxySiteCreator->resetPermissions(); goto C3f17; a1b76: return $siteEntity; goto A958f; be5a1: $siteConstraints = $this->validator->validate($siteEntity); goto A9fee; B29f5: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\x2f\x2e\x2e\x2f\162\145\x73\157\x75\x72\143\x65\163\x2f\156\x67\x69\x6e\170\57\166\150\157\163\164\x5f\x74\x65\155\160\x6c\141\x74\x65\x2f\162\145\144\151\x72\x65\x63\x74"); goto e7b52; f7e6b: $siteEntity->setVhostTemplate($vhostTemplate); goto be5a1; Fd432: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Eeaa2; E678d: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto a85d3; C259c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\56\x2f\56\x2e\x2f\x72\145\x73\157\165\x72\143\145\163\x2f\x6e\147\x69\156\x78\57\166\x68\157\x73\x74\x5f\x74\x65\x6d\x70\154\x61\164\x65\x2f\162\x65\x64\151\162\145\143\164\55\150\x74\164\160\63"); goto e6148; Bdb2a: $reverseProxySite->setUser($siteEntity->getUser()); goto dc84e; A7c59: $siteEntity->setUserPassword($siteUserPassword); goto E676a; Bf73d: B7a38: goto fefd1; b2614: $reversProxySiteCreator->reloadNginxService(); goto a252f; c9f71: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto ff3b8; f459a: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto A9c48; e43ae: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto C2075; E0fed: $reverseProxySite = new ReverseProxySite(); goto Bdb2a; e3d59: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto D5b25; b1204: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Aaa86; C556c: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A4564; Ba14d: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto E9e4e; fcbe2: $reversProxySiteCreator->createRootDirectory(); goto bde24; ff3b8: $certificateEntity->setDefaultCertificate(true); goto E678d; bde24: $reversProxySiteCreator->createLogrotateFile(); goto b1204; b2848: $rsaKeyGenerator = new RsaKeyGenerator(); goto Ba077; a909b: $vhostTemplate->build(); goto e43ae; C3f17: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto ee86d; B9b4c: ca59b: goto f7e6b; C2075: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto f1b1d; f6849: $siteEntity->setUser($siteUser); goto A7c59; Ce4de: $constraintViolationList->addAll($siteConstraints); goto e3d59; e6148: facab: goto Bc648; E9a02: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto bc87d; D3f36: $certificateEntity = $this->certificateEntityManager->createEntity(); goto d2ff4; Ee891: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto c1165; c1165: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a909b; c40b4: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\45\x73", $domainName); goto Bf73d; a85d3: $certificateEntity->setCsr($csr); goto Fd432; ee86d: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto E6b3e; bc87d: if (!(true === is_null($subdomain) || "\167\x77\x77" == $subdomain)) { goto ca59b; } goto ad5c5; A4564: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto C5614; C5614: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Ffea8; c9738: if (!(false === empty($redirectionVhostTemplate))) { goto Fa5f6; } goto Ff6cf; c58a0: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Ee891; Ff6cf: $vhostTemplate = sprintf("\45\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto c5bd8; ad5c5: if (true === isset($_ENV["\101\120\x50\x5f\110\124\x54\x50\x33"]) && "\x74\162\x75\x65" === $_ENV["\x41\120\120\137\110\124\124\x50\63"]) { goto Eccc1; } goto B29f5; A9c48: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto d42c0; Ffea8: $subdomain = false === empty($subdomain) ? $subdomain : null; goto cfa5b; e7bb2: $reversProxySiteCreator->createUser(); goto fcbe2; D441c: Eccc1: goto C259c; E676a: $siteEntity->setRootDirectory($domainName); goto E9a02; Da399: if (!(true === is_null($subdomain))) { goto B7a38; } goto c40b4; d2ff4: $certificateEntity->setSite($siteEntity); goto b2848; D5b25: throw new \Exception(implode("\x3b\40", $errorMessages)); goto bb250; a0f02: $constraintViolationList = new ConstraintViolationList(); goto Ce4de; Ad489: $siteEntity->setDomainName($domainName); goto f6849; Ea239: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto d0080; fefd1: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto c940b; } goto Faa5a; f0e96: $subjectAlternativeNames = []; goto Da399; Eea59: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto Ad489; e7b52: goto facab; goto D441c; dd600: $reverseProxySite->setDomainName($domainName); goto Ffb4c; Ffb4c: $reverseProxySite->setRegistrableDomain($registrableDomain); goto F9994; c5bd8: Fa5f6: goto B9b4c; bb250: F940b: goto D3f36; c47be: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto ba92d; Ba077: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto f0e96; d0080: $reverseProxySite->setCertificate($certificateEntity); goto f459a; E6b3e: $vhostTemplate->resetProcessors(); goto c58a0; Aaa86: $reversProxySiteCreator->createNginxVhost(); goto b2614; Bc648: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto c9738; F9994: $reverseProxySite->setSubdomain($subdomain); goto Ea239; E9e4e: $siteEntity = $this->siteEntityManager->createEntity(); goto Eea59; Dbb45: c940b: goto c47be; f1b1d: $this->siteEntityManager->updateEntity($siteEntity); goto a1b76; d6798: $csr = $csrGenerator->generate(); goto c9f71; A9fee: if (!count($siteConstraints)) { goto F940b; } goto a0f02; b83f4: $siteEntity->setCertificate($certificateEntity); goto E0fed; Eeaa2: $certificateEntity->setCertificate($selfSignedCertificate); goto b83f4; dc84e: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto dd600; cfa5b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto Ba14d; A958f: } public function installedWordPressSite(Request $request) : Response { goto cf14d; f6bba: if (false === empty($siteCredentials)) { goto A1eb5; } goto e5af8; fc966: A50b9: goto e2371; e2371: return $response; goto adf9d; cf14d: $session = $request->getSession(); goto bc93f; Aeac0: $response = $this->render("\106\162\157\156\x74\x65\x6e\x64\x2f\x53\151\164\x65\57\116\x65\167\x2f\x77\x6f\x72\144\160\162\145\x73\x73\x2d\x69\156\x73\x74\x61\x6c\x6c\145\x64\x2e\150\x74\x6d\154\x2e\164\x77\151\147", ["\163\151\x74\145\x43\x72\145\144\x65\x6e\164\151\141\154\x73" => $siteCredentials]); goto F0779; F0779: return $response; goto fc966; Ee47b: A1eb5: goto bdfa4; e5af8: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\163\x69\164\145\x73")); goto D2907; bdfa4: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto Aeac0; bc93f: $siteCredentials = $session->get("\163\151\164\x65\x43\162\x65\144\145\x6e\164\x69\x61\x6c\163"); goto f6bba; D2907: goto A50b9; goto Ee47b; adf9d: } private function renderSiteCredentials(array $siteCredentials) : string { goto Ebd2f; D82f5: return $renderedCredentials; goto c01b9; Dba91: foreach ($siteCredentials as $section => $sectionData) { goto f1185; f1185: $renderedCredentials .= $section . PHP_EOL; goto ee925; f44a9: De347: goto Cf68b; ee925: $renderedCredentials .= "\55\x2d\x2d\x2d\55\55\x2d\x2d\x2d\x2d\x2d\x2d\55\x2d\55\55\x2d\55\55\55\55\55\x2d\x2d\55\x2d\x2d\x2d\x2d\55\x2d\x2d\x2d\55\x2d\x2d\x2d\x2d\55\55\x2d\55\55\55\x2d\55\55\x2d\x2d\55\x2d\x2d\55\55" . PHP_EOL; goto e0da8; eac01: A6dfe: goto e0114; Cf68b: $renderedCredentials .= PHP_EOL; goto eac01; e0da8: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\x3a\40\x25\x73", $key, $value) . PHP_EOL; bab7c: } goto f44a9; e0114: } goto ad8e9; Ebd2f: $renderedCredentials = ''; goto Dba91; ad8e9: fb8b2: goto D82f5; c01b9: } private function getVhostTemplateEntity(string $name) : mixed { goto Bb0bb; F8cde: return $vhostTemplateEntity; goto fd1b9; Bb0bb: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto Dc7d2; C27f1: throw new \Exception($this->translator->trans("\x56\150\x6f\x73\x74\40\124\x65\155\x70\154\x61\x74\145\40\x25\166\x68\x6f\163\164\x54\145\x6d\160\154\x61\x74\x65\45\40\144\x6f\x65\x73\40\x6e\x6f\x74\x20\x65\x78\x69\163\164\x2e", ["\45\x76\150\157\x73\164\124\145\x6d\x70\x6c\x61\x74\x65\45" => $name])); goto adad2; Dc7d2: if (!(true === is_null($vhostTemplateEntity))) { goto Ac903; } goto C27f1; adad2: Ac903: goto F8cde; fd1b9: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto F9445; E939c: return $errorMessages; goto Ed9f3; F9445: $errorMessages = []; goto f321c; f321c: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\72\40\45\163", $constraint->getPropertyPath(), $constraint->getMessage()); Cca76: } goto Baa72; Baa72: bbd10: goto E939c; Ed9f3: } private function generateNameFromDomainName(string $domainName) : string { goto e1700; c3723: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto D9013; cc06e: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c3723; De253: $explodedSubdomain = explode("\x2e", $subdomain); goto b47aa; Ca01b: $name = $explodedRegistrableDomain[0] ?? ''; goto F0002; e1700: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ba19c; D6ae4: if (!(false === empty($subdomain))) { goto fccb2; } goto De253; a47c4: return $name; goto A9d91; b47aa: $name = sprintf("\45\x73\55\45\163", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto dd730; Ba19c: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto cc06e; dd730: fccb2: goto Ab413; c7b46: da2c2: goto Ca01b; ed670: $name = $explodedRegistrableDomain[0] ?? ''; goto D6ae4; Ab413: goto f9347; goto c7b46; F0002: f9347: goto a47c4; D9013: if ("\x77\167\x77" == $subdomain) { goto da2c2; } goto ed670; A9d91: } private function getUniqueDatabaseName(string $databaseName) : string { goto F5dc1; afc54: $uniqueDatabaseName = sprintf("\45\163\55\x25\163", $databaseName, $i); goto cd18b; a4464: b462d: goto B449a; Dbe42: $i++; goto B7d18; a4ab9: $uniqueDatabaseName = sprintf("\x25\x73\x2d\144\142", $uniqueDatabaseName); goto B0c3b; B7d18: if (true === $databaseExists) { goto Adebd; } goto a4464; B0c3b: Fb9a1: goto f30f8; ff9f8: $databases = $databaseConnection->getDatabases(); goto a46a4; A5440: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Cfff2; A455e: if (!(0 < $i)) { goto dfa82; } goto afc54; dd6cc: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Fb9a1; } goto a4ab9; f30f8: $i = 0; goto A5440; B449a: return $uniqueDatabaseName; goto A6be3; Ab1c5: $databaseExists = in_array($uniqueDatabaseName, $databases); goto Dbe42; F5dc1: $uniqueDatabaseName = $databaseName; goto dd6cc; cd18b: dfa82: goto Ab1c5; Cfff2: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto ff9f8; a46a4: Adebd: goto A455e; A6be3: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto c07f9; A16bf: $uniqueDatabaseUserName = sprintf("\x25\163\x2d\x25\x73", $databaseUserName, $i); goto c33f6; ee0a5: $i = 0; goto Ce37f; c33f6: c44da: goto cfcd1; Eddf0: Adfb9: goto e488d; Ce37f: c6f62: goto fdcef; feb7f: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto F3d92; } goto fea67; ba994: $i++; goto D790f; E73a4: return $uniqueDatabaseUserName; goto e5782; Ec598: F3d92: goto ee0a5; D790f: if (false === is_null($databaseUserEntity)) { goto c6f62; } goto Eddf0; fea67: $uniqueDatabaseUserName = sprintf("\x25\163\x2d\144\x62", $uniqueDatabaseUserName); goto Ec598; c07f9: $uniqueDatabaseUserName = $databaseUserName; goto feb7f; e488d: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto E73a4; cfcd1: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto ba994; fdcef: if (!(0 < $i)) { goto c44da; } goto A16bf; e5782: } private function hasPermissions() : bool { goto F1852; Ac7db: return true; goto E4556; A6361: return false; goto A5893; Fb4f0: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto bef6f; } goto Ac7db; E4556: bef6f: goto A6361; F1852: $user = $this->getUser(); goto Fb4f0; A5893: } }
